@@ -63,8 +63,8 @@ Catalyst::Authentication::Realm::SimpleDB - A simplified Catalyst authentication
     __PACKAGE__->config->{'Plugin::Authentication'} = 
         {  
             default => {
-                class => 'SimpleDB',
-                user_model => 'MyApp::User'
+                class      => 'SimpleDB',
+                user_model => 'MyApp::Schema::Users',
             }
         }
 
@@ -105,7 +105,7 @@ Your user information is stored in the session once the user is authenticated.
 =back
 
 For the above usage, only one configuration option is necessary, 'user_model'.
-B<user_model> should contain the class name of your user class. See the
+B<user_model> should contain the B<class name of your user class>. See the
 L</PREPARATION> section for info on how to set up your database for use with
 this module.
 
